from typing import Any
from typing import Generator

from ..api import APIClient as APIClient
from ..constants import DEFAULT_DATA_CHUNK_SIZE as DEFAULT_DATA_CHUNK_SIZE
from ..errors import (
    ContainerError as ContainerError,
    DockerException as DockerException,
    ImageNotFound as ImageNotFound,
    NotFound as NotFound,
    create_unexpected_kwargs_error as create_unexpected_kwargs_error,
)
from ..types import HostConfig as HostConfig, NetworkingConfig as NetworkingConfig
from ..types.io import Socket
from ..utils import version_gte as version_gte
from .images import Image as Image
from .resource import Collection as Collection, Model as Model
from _typeshed import Incomplete
from typing import NamedTuple

class Container(Model):
    @property
    def name(self) -> str: ...
    @property
    def image(self) -> str | None: ...
    @property
    def labels(self) -> dict: ...
    @property
    def status(self) -> str: ...
    @property
    def health(self) -> str: ...
    @property
    def ports(self) -> dict: ...
    def attach(self, **kwargs) -> str | Generator[str, None, None]: ...
    def attach_socket(self, **kwargs) -> Socket: ...
    def commit(
        self,
        repository: str | None = ...,
        tag: str | None = ...,
        **kwargs
    ) -> str: ...
    def diff(self) -> list[dict]: ...
    def exec_run(
        self,
        cmd: list | str,
        stdout: bool = ...,
        stderr: bool = ...,
        stdin: bool = ...,
        tty: bool = ...,
        privileged: bool = ...,
        user: str = ...,
        detach: bool = ...,
        stream: bool = ...,
        socket: bool = ...,
        environment: dict | list | None = ...,
        workdir: str | None = ...,
        demux: bool = ...,
    ) -> ExecResult: ...
    def export(self, chunk_size: int = ...): ...
    def get_archive(self, path: str, chunk_size: int = ..., encode_stream: bool = ...) -> tuple[Generator[Incomplete, None, None], dict]: ...
    def kill(self, signal: str | int | None = ...) -> None: ...
    def logs(self, **kwargs) -> Generator[str, None, None] | str: ...
    def pause(self) -> None: ...
    def put_archive(self, path: str, data: bytes | Generator[Incomplete, None, None]) -> bool: ...
    def remove(self, **kwargs) -> None: ...
    def rename(self, name: str) -> None: ...
    def resize(self, height: int, width: int) -> None: ...
    def restart(self, **kwargs): ...
    def start(self, **kwargs): ...
    def stats(self, **kwargs): ...
    def stop(self, **kwargs): ...
    def top(self, **kwargs) -> str: ...
    def unpause(self): ...
    def update(self, **kwargs) -> dict: ...
    def wait(self, **kwargs) -> dict: ...

class ContainerCollection(Collection):
    model = Container
    def run(
        self,
        image: str,
        command: str | list | None = ...,
        stdout: bool = ...,
        stderr: bool = ...,
        remove: bool = ...,
        **kwargs
    ): ...
    def create(self, image: str | Image, command: Incomplete | None = ..., **kwargs) -> Container: ...
    def get(self, container_id: str) -> Container: ...
    def list(
        self,
        all: bool = ...,
        before: str | None = ...,
        filters: dict | None = ...,
        limit: int = ...,
        since: str | None = ...,
        sparse: bool = ...,
        ignore_removed: bool = ...,
    ) -> list[Container]: ...
    def prune(self, filters: Incomplete | None = ...): ...

RUN_CREATE_KWARGS: list[str]
RUN_HOST_CONFIG_KWARGS: list[str]

class ExecResult(NamedTuple):
    exit_code: Any
    output: Any
